package com.diagbot.facade;

import com.diagbot.client.CRFServiceClient;
import com.diagbot.dto.WordBillCrfDTO;
import com.diagbot.model.ai.AIAnalyze;
import com.diagbot.model.entity.Clinical;
import com.diagbot.model.label.ChiefLabel;
import com.diagbot.model.label.DiagLabel;
import com.diagbot.model.label.PastLabel;
import com.diagbot.model.label.PresentLabel;
import com.diagbot.util.CoreUtil;
import com.diagbot.vo.IndicationPushVO;
import com.diagbot.vo.StandConvert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description: 通过业务facade
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class CommonFacade {
    @Autowired
    CRFServiceClient crfServiceClient;

    //组装好的label
    public WordBillCrfDTO crf_process(IndicationPushVO indicationPushVO){
        AIAnalyze aiAnalyze = new AIAnalyze(crfServiceClient);
        WordBillCrfDTO wordBillCrfDTO = new WordBillCrfDTO();
        aiAnalyze.aiProcess(indicationPushVO,wordBillCrfDTO);
        return wordBillCrfDTO;
    }
    //返回给图谱的词，这些词需要转换成标准词
    public StandConvert dataTypeGet(WordBillCrfDTO wordBillCrfDTO){
        StandConvert standConvert = new StandConvert();

        //所有的症状(主诉、现病史)
        List<String> clinicalList = new ArrayList<>();
        ChiefLabel chiefLabel = wordBillCrfDTO.getChiefLabel();
        clinicalList.addAll(CoreUtil.getPropertyList(chiefLabel.getClinicals()));
        PresentLabel presentLabel = wordBillCrfDTO.getPresentLabel();
        clinicalList.addAll(CoreUtil.getPropertyList(presentLabel.getClinicals()));

        //所有的疾病(主诉、现病史,诊断列表,过去史)
        DiagLabel diagLabel = wordBillCrfDTO.getDiagLabel();
        PastLabel pastLabel = wordBillCrfDTO.getPastLabel();
        List<String> diagList = new ArrayList<>();
        diagList.addAll(CoreUtil.getPropertyList(chiefLabel.getDiags()));
        diagList.addAll(CoreUtil.getPropertyList(presentLabel.getDiags()));
        diagList.addAll(CoreUtil.getPropertyList(diagLabel.getDiags()));
        diagList.addAll(CoreUtil.getPropertyList(pastLabel.getDiags()));

        standConvert.setClinicalList(clinicalList);
        standConvert.setDiaglList(diagList);
        return standConvert;
    }
    //把图谱返回的标准词set到label中
    public WordBillCrfDTO dataTypeSet(WordBillCrfDTO wordBillCrfDTO, Map<String, Map<String, String>> map){
        ChiefLabel chiefLabel = wordBillCrfDTO.getChiefLabel();
        CoreUtil.setPropertyList(chiefLabel.getClinicals(),map.get("clinicalList"));
        return wordBillCrfDTO;
    }

}
