package com.diagbot.facade;

import com.diagbot.dto.BillNeoDTO;
import com.diagbot.dto.DrugBillNeoDTO;
import com.diagbot.entity.node.Medicine;
import com.diagbot.entity.relationship.Medicine_AgeMin;
import com.diagbot.repository.MedicineNode;
import com.diagbot.repository.MedicineRepository;
import com.diagbot.vo.BillNeoVO;
import com.diagbot.vo.StandConvert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 图谱facade
 * @author: Mark
 * @time: 2018/8/6 9:11
 */
@Component
public class NeoFacade {

    @Autowired
    MedicineRepository medicineRepository;

    /**
     * 返回药品缓存信息
     *
     * @return
     */
    @Cacheable(value = "cache", key = "'drugCache'")
    public Map<String, List<String>> getDrugCache() {
        Map<String, List<String>> res = new HashMap<>();
        res.put("ddd", new ArrayList<>());
        return res;
    }



    /**
     * 处理开单合理性图谱数据
     * @param billNeoVO
     * @return
     */
    public List<BillNeoDTO> getBillNeo(BillNeoVO billNeoVO) {

        List<BillNeoDTO> billNeoDTOs = new ArrayList<>();

        for (String medname : billNeoVO.getDrugList()) {
            BillNeoDTO billNeoDTO = new BillNeoDTO();
            billNeoDTO.setName(medname);
            billNeoDTO.setDrugBillNeoDTOList(getDrugBill(medname));
        }

        return billNeoDTOs;
    }



    /**
     * 处理处方开单合理性
     */
    public List<DrugBillNeoDTO> getDrugBill(String medname) {
        List<DrugBillNeoDTO> drugBillNeoDTOS = new ArrayList<>();
        DrugBillNeoDTO drugBillNeoDTO;

        MedicineNode medicineNode = new MedicineNode();
        Medicine medicine;

        medicine = medicineRepository.findByNameIs(medname);

        if (medicine!=null) {
            drugBillNeoDTO = medicineNode.MedicinetoDrugDTO(medicine);
            System.out.println(drugBillNeoDTO);
            drugBillNeoDTOS.add(drugBillNeoDTO);
        }

        return drugBillNeoDTOS;
    }



    /**
     * 标准词转换
     *
     * @param standConvert
     *
     * @return  Map<String, Map<String, String>> -->Map<类型, Map<原始词, 标准词>>
     */
    public Map<String, Map<String, String>> standConvert(StandConvert standConvert) {
        // TODO 待处理业务
        return null;
    }

}
